# escape.manager

Manager da Escape para ser instalado com o Laravel.

## Versões

| **Laravel** | **Manager** |
|-------------|-------------|
| 5.2         | 2.4         |
| 5.2         | 2.3         |
| 5.1         | 2.2         |
| 5.0         | 2.0 - 2.1   |
| 4.2         | 1.0         |
| 4.1         | 0.9         |
| 4.0         | 0.1 - 0.9   |

## Instalação

Adicione no seu `composer.json` os seguintes itens:

```javascript
    "require": {
        "escapework/manager": "2.3.*"
    },

    "repositories": [
        {
            "type": "composer",
            "url": "http://packages.escape.ppg.br"
        }
    ],
```

E depois execute:

```sh
$ composer update
```

## Configurando

Edite o arquivo `config/app.php`, adicionando a seguinte linha no array de `providers`:

```php
    EscapeWork\Manager\Providers\ManagerServiceProvider::class,
```

**OBS**: Antes de executar o comando abaixo a base de dados local deve estar configurada.

Execute o seguinte comando:

```
$ php artisan manager:configure
```

Caso seja a primeira vez que o comando é executado, ele vai te pedir informações para criação do usuário administrador. Em ambiente local, sempre utilizamos as seguintes credenciais:

* Nome: Escape
* E-mail: `web@escape.ppg.br`
* Senha: `ninjasdaholanda`

Agora, a URL `seudominio.dev/manager` já está disponível para acesso.

***

## Utilização

### Novas rotas

Qualquer nova rota que for internamente no manager, deve ficar dentro de um grupo de rotas como este:

```php
# manager
Route::group(['prefix' => config('manager.url'), 'middleware' => ['web', manager.authenticated']], function()
{
    Route::get('noticias', ['as' => 'manager.news.index', 'uses' => 'Manager\NewsController@index']);
    Route::get('noticias/create', ['as' => 'manager.news.create', 'uses' => 'Manager\NewsController@create']);
    Route::post('noticias', ['as' => 'manager.news.store', 'uses' => 'Manager\NewsController@store']);
    Route::get('noticias/{id}/edit', ['as' => 'manager.news.edit', 'uses' => 'Manager\NewsController@edit']);
    Route::put('noticias/{id}', ['as' => 'manager.news.update', 'uses' => 'Manager\NewsController@update']);
    Route::delete('noticias/{id}', ['as' => 'manager.news.destroy', 'uses' => 'Manager\NewsController@destroy']);
});
```

### Templates

Qualquer nova view deve extender o layout master, da seguinte forma:

```php
@extends(config('manager.views.layouts.master'))

{{-- Caso queira adicionar novos stylesheets --}}
@section('styles')
    @parent
    <link href="{{ asset('css') }}" rel="stylesheet" type="text/css">
@stop

{{-- O conteúdo da página em si --}}
@section('content')
    Contúdo da página
@stop

{{-- Caso queira adicionar novos scripts --}}
@section('scripts')
    @parent
    <script src="{{ asset('file.js') }}" type="text/javascript"></script>
@stop
```

#### Menu

Para editar o menu, crie um template chamado `menu.blade.php` (de preferência, em uma subpasta chamada `manager` dentro da pasta de `views`.

Depois, altere a configuração `views.menu`, nas configurações do escape.manager, passando o caminho da view. Ex: `manager.menu`.

```php
<li class="{{ $page == 'clients' ? 'active' : null }}"><a href="{{ route('manager.clientes.index') }}">Clientes</a></li>
<li class="{{ $page == 'categories' ? 'active' : null }}"><a href="{{ route('categorias.index') }}">Categorias</a></li>
```

### Mensagens

Para exibir mensagens de notificação em seus templates, chame a view `manager::partials.messages` em seu template blade.

```
@include('manager::partials.messages')
```

### Campos de ativo/destaque e etc

Caso você tenha um campo de ativo/destaque na listagem de registros, você pode atualizá-lo facilmente utilizando um pequeno helpers em javascript.

```
    <td>
        <input type="checkbox" data-id="{{ $client->id }}" data-manager-update-checkbox="active" data-manager-update-url="{{ route('manager.clients.update', $member->id) }}" {{ $client->active ? 'checked="checked"' : null }}>
    </td>
```

É necessário declarar os atributos `data-manager-update-checkbox` com o nome do campo em questão, e o atributo `data-manager-update-url` com a rota para fazer update do registro. Obviamente que a rota registrada deve fazer o update do campo desejado.

### Atualizando ordenações

Para atualizar ordenações de registros diretamente na listagem, existe um helper também.

```
<tbody data-manager-sortable>
    @foreach ($clients as $client)
        <tr data-id="{{ $client->id }}" data-manager-sortable-url="{{ route('manager.clients.update', $client->id) }}">
            <td style="text-align: center; cursor: move; vertical-align: middle;"><span class="glyphicon glyphicon-move"></span></td>
            [...]
        </tr>
    @endforeach
</tbody>
```

Simples assim. Da mesma maneira que as atualizações checkboxes, é necessário que a rota faça o update corretamente.

### CKEditor

Para utilizar qualquer editor com o CKEditor, apenas adicione o paramêtro `data-editor` na sua textarea.

```html
    <textarea data-editor></textarea>
```

### Plugins javascript

Os seguintes plugins são instalados juntamente com o escapework/manager:

* https://github.com/aaronrussell/jquery-simply-countable
* jQuery Mask
* jQuery Validate
* jQuery UI Datepicker

***

## Dependências e Componentes

O **escape.manager** utiliza os seguintes componentes:

- [EscapeWork/LaravelSteroids](https://github.com/EscapeWork/LaravelSteroids);
- [Twitter Bootstrap](http://twitter.github.io/bootstrap/);
- [jQuery](http://jquery.com/);
- [jQuery UI](http://jqueryui.com/);
- [jQuery Validate](http://jqueryvalidation.org/);
- [CKEditor](http://ckeditor.com/).

### Alguns projetos utilizando o escapework/manager

* [Escape](http://www.escape.com.br)
* [Killjob](http://www.killjob.com.br)
* [ADVB](http://www.advb.com.br)
* [Assintecal](http://ww3.assintecal.org.br)
* [Brasil By Bags](http://www.brasilbybags.com)
* [ABIACAV](http://www.abiacav.org.br)
* [FCBB](http://www.fcbybrasil.com)
* [escape.quase](http://quase.escape.ppg.br)
* [Gabriel Rosa Leilões](http:://gabrielrosaleiloes.com.br)
* [Corso Como](http://www.corsocomo.com.br)
